# xrt_spec_dl
![CI](https://github.com/grburgess/xrt_spec_dl/workflows/CI/badge.svg?branch=master)
[![codecov](https://codecov.io/gh/grburgess/xrt_spec_dl/branch/master/graph/badge.svg)](https://codecov.io/gh/grburgess/xrt_spec_dl)
[![Documentation Status](https://readthedocs.org/projects/xrt_spec_dl/badge/?version=latest)](https://xrt_spec_dl.readthedocs.io/en/latest/?badge=latest)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.3372456.svg)](https://doi.org/10.5281/zenodo.3372456)
![PyPI](https://img.shields.io/pypi/v/xrt_spec_dl)
![PyPI - Downloads](https://img.shields.io/pypi/dm/xrt_spec_dl)

![alt text](https://raw.githubusercontent.com/grburgess/xrt_spec_dl/master/docs/media/logo.png)


simple tool to ddownload XRT time slices


* Free software: GNU General Public License v3
* Documentation: https://xrt-spec-dl.readthedocs.io.


## Features


* TODO

## Credits

